import { AppExecution, ChatStreamParams, ChatStreamResponse, ExecuteParams, ExecuteResponse, ExecutionParams, IdentifyParams } from './ts/types';
declare class AirOpsApps {
    private customFetch;
    private readonly userId?;
    private readonly workspaceId?;
    private readonly hashedUserId?;
    private readonly host;
    /**
     * App constructor
     * @param params
     * @param params.userId - User ID
     * @param params.workspaceId - Workspace ID
     * @param params.hashedUserId - Hashed User ID
     * @param params.host - Host URL optional
     */
    constructor(params: IdentifyParams);
    /**
     * Get app
     * @param appId - App Id
     * @returns App execution output
     */
    get(appId: number | string): Promise<any>;
    /**
     * Execute an app
     * @param params
     * @param params.appId - App ID
     * @param params.version - App version
     * @param params.payload - App input
     * @param params.stream - Stream enabled?
     * @param params.streamCallback - Callback function for stream
     * @param params.streamCompletedCallback - Callback function for stream completed
     * @returns - App output
     */
    execute(params: ExecuteParams): Promise<ExecuteResponse>;
    /**
     * Chat stream
     * @param params
     * @param params.message - Message to send
     * @param params.appId - App ID
     * @param params.sessionId - Session ID
     * @param params.streamCallback - Callback function for stream
     * @param params.streamCompletedCallback - Callback function for stream completed
     * @returns - Chat stream response
     */
    chatStream(params: ChatStreamParams): Promise<ChatStreamResponse>;
    /**
     * Get app execution status
     * @param params
     * @param params.appId - App Id
     * @param params.executionId - Execution Id
     * @returns App execution output
     */
    getResults(params: ExecutionParams): Promise<AppExecution>;
    /**
     * Cancel execution
     * @param params
     * @param params.appId - App ID
     * @param params.executionId - Execution ID
     */
    private cancelExecution;
    private pollExecutionResult;
    private initializePusher;
}
export default AirOpsApps;
